==> pyside-setup-opensource-src-5.14.0.zip: pyside-setup-opensource-src-5.14.0/sources/pyside2/tests/QtWebKit/webframe_test.py <==
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

import unittest
import sys

from PySide2.QtCore import QObject, SIGNAL, QUrl
from PySide2.QtWebKit import *
from PySide2.QtNetwork import QNetworkRequest

from helper import adjust_filename, UsesQApplication



class TestWebFrame(UsesQApplication):
    def load_finished(self, ok):
        self.assertTrue(ok)
        page = self.view.page()
        self.assertTrue(page)
        frame = page.mainFrame()
        self.assertTrue(frame)
        meta = frame.metaData()
        self.assertEqual(meta['description'], ['PySide Test METADATA.'])
        self.app.quit()

    def testMetaData(self):
        self.view = QWebView()
        QObject.connect(self.view, SIGNAL('loadFinished(bool)'),
                        self.load_finished)
        url = QUrl.fromLocalFile(adjust_filename('fox.html', __file__))
        self.view.setUrl(url)
        self.app.exec_()


if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-5.15.5.zip: pyside-setup-opensource-src-5.15.5/sources/pyside2/tests/QtWebKit/webframe_test.py <==
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

import os
import sys
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from init_paths import init_test_paths
init_test_paths(False)

from PySide2.QtCore import QObject, SIGNAL, QUrl
from PySide2.QtWebKit import *
from PySide2.QtNetwork import QNetworkRequest

from helper.helper import adjust_filename
from helper.usesqapplication import UsesQApplication


class TestWebFrame(UsesQApplication):
    def load_finished(self, ok):
        self.assertTrue(ok)
        page = self.view.page()
        self.assertTrue(page)
        frame = page.mainFrame()
        self.assertTrue(frame)
        meta = frame.metaData()
        self.assertEqual(meta['description'], ['PySide Test METADATA.'])
        self.app.quit()

    def testMetaData(self):
        self.view = QWebView()
        QObject.connect(self.view, SIGNAL('loadFinished(bool)'),
                        self.load_finished)
        url = QUrl.fromLocalFile(adjust_filename('fox.html', __file__))
        self.view.setUrl(url)
        self.app.exec_()


if __name__ == '__main__':
    unittest.main()
